@@ -7,5 +7,8 @@ cache_key_prefix = getattr(
 cache = getattr(settings, "COLLECTFAST_CACHE", "default")
 threads = getattr(settings, "COLLECTFAST_THREADS", False)
 enabled = getattr(settings, "COLLECTFAST_ENABLED", True)
-preload_metadata_enabled = True is getattr(
-    settings, 'AWS_PRELOAD_METADATA', False)
+is_gzipped = getattr(settings, "AWS_IS_GZIPPED", False)
+gzip_content_types = getattr(
+    settings, "GZIP_CONTENT_TYPES", (
+        "text/css", "text/javascript", "application/javascript",
+        "application/x-javascript", "image/svg+xml"))
